summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2014-11-04 13:31:01 +0200
committerNoel Grandin <noel@peralex.com>2014-11-04 14:45:58 +0200
commitd1974ddf3a84d2a4a3082920f812857c85218fc2 (patch)
tree449688edfbd393ce3085ef58b1c46f156fe9c5d5
parent736d25f9e373ce19be59e84667a6dd64b1253cd3 (diff)
some random renaming of Wink fields -> Angle
Change-Id: Icd4df8610072f5283276738896cb5c01762838ea
-rw-r--r--include/svx/svdocirc.hxx8
-rw-r--r--include/svx/svdopath.hxx2
-rw-r--r--svx/source/svdraw/svdedtv1.cxx12
-rw-r--r--svx/source/svdraw/svdoashp.cxx18
-rw-r--r--svx/source/svdraw/svdocirc.cxx40
-rw-r--r--svx/source/svdraw/svdomeas.cxx42
-rw-r--r--svx/source/svdraw/svdopath.cxx50
-rw-r--r--vcl/source/filter/sgvmain.cxx12
-rw-r--r--vcl/source/filter/sgvmain.hxx4
9 files changed, 94 insertions, 94 deletions
diff --git a/include/svx/svdopath.hxx b/include/svx/svdopath.hxx
index b9cb18f73630..ea1bd16ff902 100644
--- a/include/svx/svdopath.hxx
+++ b/include/svx/svdopath.hxx
@@ -62,7 +62,7 @@ protected:
// helper functions for GET, SET, INS etc. PNT
void ImpSetClosed(bool bClose);
void ImpForceKind();
- void ImpForceLineWink();
+ void ImpForceLineAngle();
ImpPathForDragAndCreate& impGetDAC() const;
void impDeleteDAC() const;
diff --git a/svx/source/svdraw/svdedtv1.cxx b/svx/source/svdraw/svdedtv1.cxx
index cd8fc5e28946..d2ce026fd042 100644
--- a/svx/source/svdraw/svdedtv1.cxx
+++ b/svx/source/svdraw/svdedtv1.cxx
@@ -308,9 +308,9 @@ long SdrEditView::GetMarkedObjRotate() const
//for (sal_uIntPtr nm=0; nm<nMarkAnz && bOk; nm++) {
// SdrMark* pM=GetSdrMarkByIndex(nm);
// SdrObject* pO=pM->GetMarkedSdrObj();
- // long nWink2=pO->GetRotateAngle();
- // if (b1st) nWink=nWink2;
- // else if (nWink2!=nWink) bOk=false;
+ // long nAngle2=pO->GetRotateAngle();
+ // if (b1st) nWink=nAngle2;
+ // else if (nAngle2!=nWink) bOk=false;
// b1st=false;
//}
//if (!bOk) nWink=0;
@@ -459,9 +459,9 @@ long SdrEditView::GetMarkedObjShear() const
for (size_t nm=0; nm<nMarkAnz && bOk; ++nm) {
SdrMark* pM=GetSdrMarkByIndex(nm);
SdrObject* pO=pM->GetMarkedSdrObj();
- long nWink2=pO->GetShearAngle();
- if (b1st) nWink=nWink2;
- else if (nWink2!=nWink) bOk=false;
+ long nAngle2=pO->GetShearAngle();
+ if (b1st) nWink=nAngle2;
+ else if (nAngle2!=nWink) bOk=false;
b1st=false;
}
if (nWink>SDRMAXSHEAR) nWink=SDRMAXSHEAR;
diff --git a/svx/source/svdraw/svdoashp.cxx b/svx/source/svdraw/svdoashp.cxx
index 9108eaeb9349..c73a05b97e04 100644
--- a/svx/source/svdraw/svdoashp.cxx
+++ b/svx/source/svdraw/svdoashp.cxx
@@ -1651,9 +1651,9 @@ void SdrObjCustomShape::NbcRotate( const Point& rRef, long nWink, double sn, dou
if ( bMirroredY )
nSwap ^= 1;
- double fWink = nWink; // updating to our new object rotation
- fWink /= 100.0;
- fObjectRotation = fmod( nSwap ? fObjectRotation - fWink : fObjectRotation + fWink, 360.0 );
+ double fAngle = nWink; // updating to our new object rotation
+ fAngle /= 100.0;
+ fObjectRotation = fmod( nSwap ? fObjectRotation - fAngle : fObjectRotation + fAngle, 360.0 );
if ( fObjectRotation < 0 )
fObjectRotation = 360 + fObjectRotation;
@@ -1690,13 +1690,13 @@ void SdrObjCustomShape::NbcMirror( const Point& rRef1, const Point& rRef2 )
// update fObjectRotation
long nTextObjRotation = aGeo.nRotationAngle;
- double fWink = nTextObjRotation;
+ double fAngle = nTextObjRotation;
- fWink /= 100.0;
+ fAngle /= 100.0;
bool bSingleFlip = (IsMirroredX()!= IsMirroredY());
- fObjectRotation = fmod( bSingleFlip ? -fWink : fWink, 360.0 );
+ fObjectRotation = fmod( bSingleFlip ? -fAngle : fAngle, 360.0 );
if ( fObjectRotation < 0 )
{
@@ -1720,13 +1720,13 @@ void SdrObjCustomShape::NbcShear( const Point& rRef, long nWink, double tn, bool
// updating fObjectRotation
long nTextObjRotation = aGeo.nRotationAngle;
- double fWink = nTextObjRotation;
+ double fAngle = nTextObjRotation;
- fWink /= 100.0;
+ fAngle /= 100.0;
bool bSingleFlip = (IsMirroredX()!= IsMirroredY());
- fObjectRotation = fmod( bSingleFlip ? -fWink : fWink, 360.0 );
+ fObjectRotation = fmod( bSingleFlip ? -fAngle : fAngle, 360.0 );
if ( fObjectRotation < 0 )
{
diff --git a/svx/source/svdraw/svdocirc.cxx b/svx/source/svdraw/svdocirc.cxx
index f927e1a923c4..44bf9cf49ac2 100644
--- a/svx/source/svdraw/svdocirc.cxx
+++ b/svx/source/svdraw/svdocirc.cxx
@@ -128,10 +128,10 @@ SdrCircObj::SdrCircObj(SdrObjKind eNewKind, const Rectangle& rRect):
SdrCircObj::SdrCircObj(SdrObjKind eNewKind, const Rectangle& rRect, long nNewStartWink, long nNewEndWink):
SdrRectObj(rRect)
{
- long nWinkDif=nNewEndWink-nNewStartWink;
+ long nAngleDif=nNewEndWink-nNewStartWink;
nStartAngle=NormAngle360(nNewStartWink);
nEndAngle=NormAngle360(nNewEndWink);
- if (nWinkDif==36000) nEndAngle+=nWinkDif; // full circle
+ if (nAngleDif==36000) nEndAngle+=nAngleDif; // full circle
meCircleKind=eNewKind;
bClosedObj=eNewKind!=OBJ_CARC;
}
@@ -478,9 +478,9 @@ bool SdrCircObj::hasSpecialDrag() const
bool SdrCircObj::beginSpecialDrag(SdrDragStat& rDrag) const
{
- const bool bWink(rDrag.GetHdl() && HDL_CIRC == rDrag.GetHdl()->GetKind());
+ const bool bAngle(rDrag.GetHdl() && HDL_CIRC == rDrag.GetHdl()->GetKind());
- if(bWink)
+ if(bAngle)
{
if(1 == rDrag.GetHdl()->GetPointNum() || 2 == rDrag.GetHdl()->GetPointNum())
{
@@ -495,9 +495,9 @@ bool SdrCircObj::beginSpecialDrag(SdrDragStat& rDrag) const
bool SdrCircObj::applySpecialDrag(SdrDragStat& rDrag)
{
- const bool bWink(rDrag.GetHdl() && HDL_CIRC == rDrag.GetHdl()->GetKind());
+ const bool bAngle(rDrag.GetHdl() && HDL_CIRC == rDrag.GetHdl()->GetKind());
- if(bWink)
+ if(bAngle)
{
Point aPt(rDrag.GetNow());
@@ -593,9 +593,9 @@ OUString SdrCircObj::getSpecialDragComment(const SdrDragStat& rDrag) const
}
else
{
- const bool bWink(rDrag.GetHdl() && HDL_CIRC == rDrag.GetHdl()->GetKind());
+ const bool bAngle(rDrag.GetHdl() && HDL_CIRC == rDrag.GetHdl()->GetKind());
- if(bWink)
+ if(bAngle)
{
const sal_Int32 nWink(1 == rDrag.GetHdl()->GetPointNum() ? nStartAngle : nEndAngle);
@@ -852,10 +852,10 @@ void SdrCircObj::NbcResize(const Point& rRef, const Fraction& xFact, const Fract
nE0-=aGeo.nRotationAngle;
}
}
- long nWinkDif=nE0-nS0;
+ long nAngleDif=nE0-nS0;
nStartAngle=NormAngle360(nS0);
nEndAngle =NormAngle360(nE0);
- if (nWinkDif==36000) nEndAngle+=nWinkDif; // full circle
+ if (nAngleDif==36000) nEndAngle+=nAngleDif; // full circle
}
}
SetXPolyDirty();
@@ -921,10 +921,10 @@ void SdrCircObj::NbcMirror(const Point& rRef1, const Point& rRef2)
// because it's mirrored, the angles are swapped, too
nStartAngle=GetAngle(aTmpPt2);
nEndAngle =GetAngle(aTmpPt1);
- long nWinkDif=nEndAngle-nStartAngle;
+ long nAngleDif=nEndAngle-nStartAngle;
nStartAngle=NormAngle360(nStartAngle);
nEndAngle =NormAngle360(nEndAngle);
- if (nWinkDif==36000) nEndAngle+=nWinkDif; // full circle
+ if (nAngleDif==36000) nEndAngle+=nAngleDif; // full circle
}
SetXPolyDirty();
ImpSetCircInfoToAttr();
@@ -1088,15 +1088,15 @@ void SdrCircObj::ImpSetAttrToCircInfo()
sal_Int32 nNewEnd = static_cast<const SdrAngleItem&>(rSet.Get(SDRATTR_CIRCENDANGLE)).GetValue();
bool bKindChg = meCircleKind != eNewKind;
- bool bWinkChg = nNewStart != nStartAngle || nNewEnd != nEndAngle;
+ bool bAngleChg = nNewStart != nStartAngle || nNewEnd != nEndAngle;
- if(bKindChg || bWinkChg)
+ if(bKindChg || bAngleChg)
{
meCircleKind = eNewKind;
nStartAngle = nNewStart;
nEndAngle = nNewEnd;
- if(bKindChg || (meCircleKind != OBJ_CIRC && bWinkChg))
+ if(bKindChg || (meCircleKind != OBJ_CIRC && bAngleChg))
{
SetXPolyDirty();
SetRectsDirty();
@@ -1117,10 +1117,10 @@ void SdrCircObj::ImpSetCircInfoToAttr()
eNewKindA = SDRCIRC_CUT;
SdrCircKind eOldKindA = static_cast<const SdrCircKindItem&>(rSet.Get(SDRATTR_CIRCKIND)).GetValue();
- sal_Int32 nOldStartWink = static_cast<const SdrAngleItem&>(rSet.Get(SDRATTR_CIRCSTARTANGLE)).GetValue();
- sal_Int32 nOldEndWink = static_cast<const SdrAngleItem&>(rSet.Get(SDRATTR_CIRCENDANGLE)).GetValue();
+ sal_Int32 nOldStartAngle = static_cast<const SdrAngleItem&>(rSet.Get(SDRATTR_CIRCSTARTANGLE)).GetValue();
+ sal_Int32 nOldEndAngle = static_cast<const SdrAngleItem&>(rSet.Get(SDRATTR_CIRCENDANGLE)).GetValue();
- if(eNewKindA != eOldKindA || nStartAngle != nOldStartWink || nEndAngle != nOldEndWink)
+ if(eNewKindA != eOldKindA || nStartAngle != nOldStartAngle || nEndAngle != nOldEndAngle)
{
// since SetItem() implicitly calls ImpSetAttrToCircInfo()
// setting the item directly is necessary here.
@@ -1129,12 +1129,12 @@ void SdrCircObj::ImpSetCircInfoToAttr()
GetProperties().SetObjectItemDirect(SdrCircKindItem(eNewKindA));
}
- if(nStartAngle != nOldStartWink)
+ if(nStartAngle != nOldStartAngle)
{
GetProperties().SetObjectItemDirect(makeSdrCircStartAngleItem(nStartAngle));
}
- if(nEndAngle != nOldEndWink)
+ if(nEndAngle != nOldEndAngle)
{
GetProperties().SetObjectItemDirect(makeSdrCircEndAngleItem(nEndAngle));
}
diff --git a/svx/source/svdraw/svdomeas.cxx b/svx/source/svdraw/svdomeas.cxx
index eb5e6a52f5a0..050269eefcdc 100644
--- a/svx/source/svdraw/svdomeas.cxx
+++ b/svx/source/svdraw/svdomeas.cxx
@@ -306,9 +306,9 @@ struct ImpMeasurePoly
Rectangle aTextRect;
Size aTextSize;
long nLineLen;
- long nLineWink;
- long nTextWink;
- long nHlpWink;
+ long nLineAngle;
+ long nTextAngle;
+ long nHlpAngle;
double nLineSin;
double nLineCos;
double nHlpSin;
@@ -452,30 +452,30 @@ void SdrMeasureObj::ImpCalcGeometrics(const ImpMeasureRec& rRec, ImpMeasurePoly&
rPol.nArrow2Len=nArrow2Len;
rPol.bArrow2Center=bArrow2Center;
- rPol.nLineWink=GetAngle(aDelt);
- double a=rPol.nLineWink*nPi180;
+ rPol.nLineAngle=GetAngle(aDelt);
+ double a=rPol.nLineAngle*nPi180;
double nLineSin=sin(a);
double nLineCos=cos(a);
rPol.nLineSin=nLineSin;
rPol.nLineCos=nLineCos;
- rPol.nTextWink=rPol.nLineWink;
- if (rRec.bTextRota90) rPol.nTextWink+=9000;
+ rPol.nTextAngle=rPol.nLineAngle;
+ if (rRec.bTextRota90) rPol.nTextAngle+=9000;
rPol.bAutoUpsideDown=false;
if (rRec.bTextAutoAngle) {
- long nTmpAngle=NormAngle360(rPol.nTextWink-rRec.nTextAutoAngleView);
+ long nTmpAngle=NormAngle360(rPol.nTextAngle-rRec.nTextAutoAngleView);
if (nTmpAngle>=18000) {
- rPol.nTextWink+=18000;
+ rPol.nTextAngle+=18000;
rPol.bAutoUpsideDown=true;
}
}
- if (rRec.bTextUpsideDown) rPol.nTextWink+=18000;
- rPol.nTextWink=NormAngle360(rPol.nTextWink);
- rPol.nHlpWink=rPol.nLineWink+9000;
- if (rRec.bBelowRefEdge) rPol.nHlpWink+=18000;
- rPol.nHlpWink=NormAngle360(rPol.nHlpWink);
+ if (rRec.bTextUpsideDown) rPol.nTextAngle+=18000;
+ rPol.nTextAngle=NormAngle360(rPol.nTextAngle);
+ rPol.nHlpAngle=rPol.nLineAngle+9000;
+ if (rRec.bBelowRefEdge) rPol.nHlpAngle+=18000;
+ rPol.nHlpAngle=NormAngle360(rPol.nHlpAngle);
double nHlpSin=nLineCos;
double nHlpCos=-nLineSin;
if (rRec.bBelowRefEdge) {
@@ -720,8 +720,8 @@ void SdrMeasureObj::TakeUnrotatedSnapRect(Rectangle& rRect) const
aTextPos.Y()-=aTextSize2.Width();
}
}
- if (aMPol.nTextWink!=aGeo.nRotationAngle) {
- ((SdrMeasureObj*)this)->aGeo.nRotationAngle=aMPol.nTextWink;
+ if (aMPol.nTextAngle!=aGeo.nRotationAngle) {
+ ((SdrMeasureObj*)this)->aGeo.nRotationAngle=aMPol.nTextAngle;
((SdrMeasureObj*)this)->aGeo.RecalcSinCos();
}
RotatePoint(aTextPos,aPt1b,aMPol.nLineSin,aMPol.nLineCos);
@@ -730,8 +730,8 @@ void SdrMeasureObj::TakeUnrotatedSnapRect(Rectangle& rRect) const
rRect.Justify();
((SdrMeasureObj*)this)->aRect=rRect;
- if (aMPol.nTextWink!=aGeo.nRotationAngle) {
- ((SdrMeasureObj*)this)->aGeo.nRotationAngle=aMPol.nTextWink;
+ if (aMPol.nTextAngle!=aGeo.nRotationAngle) {
+ ((SdrMeasureObj*)this)->aGeo.nRotationAngle=aMPol.nTextAngle;
((SdrMeasureObj*)this)->aGeo.RecalcSinCos();
}
}
@@ -795,7 +795,7 @@ SdrHdl* SdrMeasureObj::GetHdl(sal_uInt32 nHdlNum) const
} // switch
SdrHdl* pHdl=new ImpMeasureHdl(aPt,HDL_USER);
pHdl->SetObjHdlNum(nHdlNum);
- pHdl->SetRotationAngle(aMPol.nLineWink);
+ pHdl->SetRotationAngle(aMPol.nLineAngle);
return pHdl;
}
@@ -904,8 +904,8 @@ OUString SdrMeasureObj::getSpecialDragComment(const SdrDragStat& /*rDrag*/) cons
void SdrMeasureObj::ImpEvalDrag(ImpMeasureRec& rRec, const SdrDragStat& rDrag) const
{
- long nLineWink=GetAngle(rRec.aPt2-rRec.aPt1);
- double a=nLineWink*nPi180;
+ long nLineAngle=GetAngle(rRec.aPt2-rRec.aPt1);
+ double a=nLineAngle*nPi180;
double nSin=sin(a);
double nCos=cos(a);
diff --git a/svx/source/svdraw/svdopath.cxx b/svx/source/svdraw/svdopath.cxx
index fc700a8bdb59..c88fa0bbcebe 100644
--- a/svx/source/svdraw/svdopath.cxx
+++ b/svx/source/svdraw/svdopath.cxx
@@ -244,8 +244,8 @@ struct ImpPathCreateUser : public SdrDragStatUserData
Point aRectP2;
Point aRectP3;
long nCircRadius;
- long nCircStWink;
- long nCircRelWink;
+ long nCircStAngle;
+ long nCircRelAngle;
bool bBezier;
bool bBezHasCtrl0;
bool bCurve;
@@ -260,7 +260,7 @@ struct ImpPathCreateUser : public SdrDragStatUserData
SdrObjKind eAktKind;
public:
- ImpPathCreateUser(): nCircRadius(0),nCircStWink(0),nCircRelWink(0),
+ ImpPathCreateUser(): nCircRadius(0),nCircStAngle(0),nCircRelAngle(0),
bBezier(false),bBezHasCtrl0(false),bCurve(false),bCircle(false),bAngleSnap(false),bLine(false),bLine90(false),bRect(false),
bMixedCreate(false),nBezierStartPoint(0),eStartKind(OBJ_NONE),eAktKind(OBJ_NONE) { }
@@ -333,13 +333,13 @@ bool ImpPathCreateUser::CalcCircle(const Point& rP1, const Point& rP2, const Poi
nRad=std::abs(Round(nR));
}
if (dAngle<18000) {
- nCircStWink=NormAngle360(nTangAngle-9000);
- nCircRelWink=NormAngle360(2*dAngle);
+ nCircStAngle=NormAngle360(nTangAngle-9000);
+ nCircRelAngle=NormAngle360(2*dAngle);
aCircCenter.X()+=Round(nRad*cos((nTangAngle+9000)*nPi180));
aCircCenter.Y()-=Round(nRad*sin((nTangAngle+9000)*nPi180));
} else {
- nCircStWink=NormAngle360(nTangAngle+9000);
- nCircRelWink=-NormAngle360(36000-2*dAngle);
+ nCircStAngle=NormAngle360(nTangAngle+9000);
+ nCircRelAngle=-NormAngle360(36000-2*dAngle);
aCircCenter.X()+=Round(nRad*cos((nTangAngle-9000)*nPi180));
aCircCenter.Y()-=Round(nRad*sin((nTangAngle-9000)*nPi180));
}
@@ -347,32 +347,32 @@ bool ImpPathCreateUser::CalcCircle(const Point& rP1, const Point& rP2, const Poi
if (bAngleSnap) {
long nSA=pView->GetSnapAngle();
if (nSA!=0) { // angle snapping
- bool bNeg=nCircRelWink<0;
- if (bNeg) nCircRelWink=-nCircRelWink;
- nCircRelWink+=nSA/2;
- nCircRelWink/=nSA;
- nCircRelWink*=nSA;
- nCircRelWink=NormAngle360(nCircRelWink);
- if (bNeg) nCircRelWink=-nCircRelWink;
+ bool bNeg=nCircRelAngle<0;
+ if (bNeg) nCircRelAngle=-nCircRelAngle;
+ nCircRelAngle+=nSA/2;
+ nCircRelAngle/=nSA;
+ nCircRelAngle*=nSA;
+ nCircRelAngle=NormAngle360(nCircRelAngle);
+ if (bNeg) nCircRelAngle=-nCircRelAngle;
}
}
nCircRadius=nRad;
- if (nRad==0 || std::abs(nCircRelWink)<5) bRet=false;
+ if (nRad==0 || std::abs(nCircRelAngle)<5) bRet=false;
bCircle=bRet;
return bRet;
}
XPolygon ImpPathCreateUser::GetCirclePoly() const
{
- if (nCircRelWink>=0) {
+ if (nCircRelAngle>=0) {
XPolygon aXP(aCircCenter,nCircRadius,nCircRadius,
- sal_uInt16((nCircStWink+5)/10),sal_uInt16((nCircStWink+nCircRelWink+5)/10),false);
+ sal_uInt16((nCircStAngle+5)/10),sal_uInt16((nCircStAngle+nCircRelAngle+5)/10),false);
aXP[0]=aCircStart; aXP.SetFlags(0,XPOLY_SMOOTH);
if (!bAngleSnap) aXP[aXP.GetPointCount()-1]=aCircEnd;
return aXP;
} else {
XPolygon aXP(aCircCenter,nCircRadius,nCircRadius,
- sal_uInt16(NormAngle360(nCircStWink+nCircRelWink+5)/10),sal_uInt16((nCircStWink+5)/10),false);
+ sal_uInt16(NormAngle360(nCircStAngle+nCircRelAngle+5)/10),sal_uInt16((nCircStAngle+5)/10),false);
sal_uInt16 nAnz=aXP.GetPointCount();
for (sal_uInt16 nNum=nAnz/2; nNum>0;) {
nNum--; // reverse XPoly's order of points
@@ -759,8 +759,8 @@ bool ImpPathForDragAndCreate::movePathDrag( SdrDragStat& rDrag ) const
long nAngle1=GetAngle(aPt);
aPt=rDrag.GetNow();
aPt-=mpSdrPathDragData->aXP[nPrevPnt];
- long nWink2=GetAngle(aPt);
- long nDiff=nAngle1-nWink2;
+ long nAngle2=GetAngle(aPt);
+ long nDiff=nAngle1-nAngle2;
nDiff=std::abs(nDiff);
mpSdrPathDragData->bEliminate=nDiff<=rDrag.GetView()->GetEliminatePolyPointLimitAngle();
if (mpSdrPathDragData->bEliminate) { // adapt position, Smooth is true for the ends
@@ -957,7 +957,7 @@ OUString ImpPathForDragAndCreate::getSpecialDragComment(const SdrDragStat& rDrag
if(pU->bCircle)
{
- mrSdrPathObject.GetModel()->TakeAngleStr(std::abs(pU->nCircRelWink), aMetr);
+ mrSdrPathObject.GetModel()->TakeAngleStr(std::abs(pU->nCircRelAngle), aMetr);
aStr += aMetr;
aStr += " r=";
mrSdrPathObject.GetModel()->TakeMetricStr(pU->nCircRadius, aMetr, true);
@@ -1701,7 +1701,7 @@ static Rectangle lcl_ImpGetBoundRect(const basegfx::B2DPolyPolygon& rPolyPolygon
FRound(aRange.getMaxX()), FRound(aRange.getMaxY()));
}
-void SdrPathObj::ImpForceLineWink()
+void SdrPathObj::ImpForceLineAngle()
{
if(OBJ_LINE == meKind && lcl_ImpIsLine(GetPathPoly()))
{
@@ -1757,7 +1757,7 @@ void SdrPathObj::ImpForceKind()
if (meKind==OBJ_LINE)
{
- ImpForceLineWink();
+ ImpForceLineAngle();
}
else
{
@@ -1778,7 +1778,7 @@ void SdrPathObj::ImpForceKind()
// which is basically wrong. To make the SdrText methods which deal with aRect directly
// work it is necessary to always keep aRect updated. This e.g. not done after a Clone()
// command for SdrPathObj. Since adding this update mechanism with #101412# to
- // ImpForceLineWink() for lines was very successful, i add it to where ImpForceLineWink()
+ // ImpForceLineAngle() for lines was very successful, i add it to where ImpForceLineAngle()
// was called, once here below and once on a 2nd place below.
// #i10659# for SdrTextObj, keep aRect up to date
@@ -2522,7 +2522,7 @@ void SdrPathObj::NbcSetPoint(const Point& rPnt, sal_uInt32 nHdlNum)
if(meKind==OBJ_LINE)
{
- ImpForceLineWink();
+ ImpForceLineAngle();
}
else
{
diff --git a/vcl/source/filter/sgvmain.cxx b/vcl/source/filter/sgvmain.cxx
index b0f7bf327ad1..f7b24328f072 100644
--- a/vcl/source/filter/sgvmain.cxx
+++ b/vcl/source/filter/sgvmain.cxx
@@ -235,8 +235,8 @@ SvStream& ReadCircType(SvStream& rInp, CircType& rCirc)
SWAPPOINT(rCirc.Radius);
SWAPPOINT(rCirc.Center);
rCirc.RotationAngle = OSL_SWAPWORD(rCirc.RotationAngle );
- rCirc.StartWink = OSL_SWAPWORD(rCirc.StartWink);
- rCirc.RelWink = OSL_SWAPWORD(rCirc.RelWink );
+ rCirc.StartAngle = OSL_SWAPWORD(rCirc.StartAngle);
+ rCirc.RelAngle = OSL_SWAPWORD(rCirc.RelAngle );
#endif
return rInp;
}
@@ -615,11 +615,11 @@ void CircType::Draw(OutputDevice& rOut)
double sn,cs;
a.x=Center.x+Radius.x; a.y=Center.y; b=a;
- sn=sin(double(StartWink)*3.14159265359/18000);
- cs=cos(double(StartWink)*3.14159265359/18000);
+ sn=sin(double(StartAngle)*3.14159265359/18000);
+ cs=cos(double(StartAngle)*3.14159265359/18000);
RotatePoint(a,Center.x,Center.y,sn,cs);
- sn=sin(double(StartWink+RelWink)*3.14159265359/18000);
- cs=cos(double(StartWink+RelWink)*3.14159265359/18000);
+ sn=sin(double(StartAngle+RelAngle)*3.14159265359/18000);
+ cs=cos(double(StartAngle+RelAngle)*3.14159265359/18000);
RotatePoint(b,Center.x,Center.y,sn,cs);
if (Radius.x!=Radius.y) {
if (Radius.x<1) Radius.x=1;
diff --git a/vcl/source/filter/sgvmain.hxx b/vcl/source/filter/sgvmain.hxx
index a099f2462571..41c20a9f9ca4 100644
--- a/vcl/source/filter/sgvmain.hxx
+++ b/vcl/source/filter/sgvmain.hxx
@@ -236,8 +236,8 @@ public:
PointType Center; // center
PointType Radius; // radius
sal_uInt16 RotationAngle; // only ellipses
- sal_uInt16 StartWink; // and not for full circles
- sal_uInt16 RelWink; // and full ellipses
+ sal_uInt16 StartAngle; // and not for full circles
+ sal_uInt16 RelAngle; // and full ellipses
friend SvStream& ReadCircType(SvStream& rIStream, CircType& rCirc);
virtual void Draw(OutputDevice& rOut) SAL_OVERRIDE;
};
diff --git a/include/svx/svdocirc.hxx b/include/svx/svdocirc.hxx
index 37d9a0c75e1c..14e8f4658c91 100644
--- a/include/svx/svdocirc.hxx
+++ b/include/svx/svdocirc.hxx
@@ -74,10 +74,10 @@ public:
SdrCircObj(SdrObjKind eNewKind, const Rectangle& rRect);
// 0=0.00Deg=3h 9000=90.00Deg=12h 18000=180.00Deg=9h 27000=270.00Deg=6h
- // The circle is build up from StartWink to EndWink anti-clockwise.
- // If nNewStartWink==nNewEndWink, then arc has an angle of 0 degrees.
- // If nNewStartWink+36000==nNewEndWink, then the arc has angle of 360 degrees.
- SdrCircObj(SdrObjKind eNewKind, const Rectangle& rRect, long nNewStartWink, long nNewEndWink);
+ // The circle is build up from StartAngle to EndWink anti-clockwise.
+ // If nNewStartAngle==nNewEndWink, then arc has an angle of 0 degrees.
+ // If nNewStartAngle+36000==nNewEndWink, then the arc has angle of 360 degrees.
+ SdrCircObj(SdrObjKind eNewKind, const Rectangle& rRect, long nNewStartAngle, long nNewEndWink);
virtual ~SdrCircObj();
virtual void TakeObjInfo(SdrObjTransformInfoRec& rInfo) const SAL_OVERRIDE;